<TS version="2.1" language="gu">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation type="unfinished">સરનામું અથવા લેબલ બદલવા માટે જમણું-ક્લિક કરો</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation type="unfinished">નવું સરનામું બનાવો</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation type="unfinished">નવું</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation type="unfinished">હાલમાં પસંદ કરેલા સરનામાંને સિસ્ટમ ક્લિપબોર્ડ પર નકલ કરો</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation type="unfinished">&amp; નકલ કરો</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation type="unfinished">&amp; બંધ કરો</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation type="unfinished">સૂચિમાંથી હાલમાં પસંદ કરેલું સરનામું કાઢી નાખો</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation type="unfinished">શોધવા માટે સરનામું અથવા લેબલ દાખલ કરો</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">હાલ માં પસંદ કરેલ માહિતી ને ફાઇલમાં નિકાસ કરો</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">&amp; નિકાસ કરો</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="unfinished">&amp; કાઢી નાખો</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation type="unfinished">સિક્કા મોકલવા માટે સરનામું પસંદ કરો</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation type="unfinished">સિક્કા મેળવવા માટે સરનામું પસંદ કરો</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation type="unfinished">&amp; પસંદ કરો</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation type="unfinished">મોકલવા માટે ના સરનામાં</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation type="unfinished">મેળવવા માટે ના સરનામાં</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation type="unfinished">આ તમારા ચુકવણી કરવા માટે ના સરનામાં છે, હંમેશા કિંમત અને મોકલવાના ના સરનામાં ચકાસી લેવા સિક્કા આપતા પહેલા.</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for receiving payments. Use the 'Create new receiving address' button in the receive tab to create new addresses.
Signing is only possible with addresses of the type 'legacy'.</source>
        <translation type="unfinished">આ તમારુ ચૂકવણું લેવા માટે નું સરનામા છે. નવું સરનામું બનાવા માટે "મેળવવા" માટે ની ટેબ માં "ચૂકવણું લેવા માટે નવું સરનામુ બનાવો" બટન વાપરો.
ડિજિટલી સહી કરવા માટે 'legacy એટલેકે જુના પ્રકાર નુ' પ્રકાર નું સરનામું હોવું જરૂરી છે.</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation type="unfinished">&amp; સરનામુ નકલ કરો</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation type="unfinished">નકલ &amp; લેબલ</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished">&amp; બદલો</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation type="unfinished">સરનામાં ની સૂચિ નો નિકાસ કરો</translation>
    </message>
    <message>
        <source>Comma separated file</source>
        <extracomment>Expanded name of the CSV file format. See: https://en.wikipedia.org/wiki/Comma-separated_values.</extracomment>
        <translation type="unfinished">અલ્પવિરામથી વિભાજિત ફાઇલ</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation type="unfinished">નિકાસ ની પ્ર્રાક્રિયા નિષ્ફળ ગયેલ છે</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation type="unfinished">ચિઠ્ઠી</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">સરનામુ</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">લેબલ નથી</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation type="unfinished">ગુપ્ત શબ્દ માટે નુ ડાયલોગ</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation type="unfinished">ગુપ્ત શબ્દ દાખલ કરો </translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation type="unfinished">નવો ગુપ્ત શબ્દ</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation type="unfinished">ગુપ્ત શબ્દ ફરી નાખો</translation>
    </message>
    <message>
        <source>Show passphrase</source>
        <translation type="unfinished">ગુપ્ત શબ્દ જોવો</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation type="unfinished">સાંકેતિક પાકીટ</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation type="unfinished">પાકીટ અવલોકન જરુરી છે પાકીટ ઓપન કરવા માટે</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation type="unfinished">પાકીટ ખુલ્લુ</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation type="unfinished">ગુપ્ત શબ્દ બદલો</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation type="unfinished">એન્ક્રિપ્શન ખાતરી કરો </translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR BITCOINS&lt;/b&gt;!</source>
        <translation type="unfinished">ચેતવણી: જો તમે તમારું વletલેટ એન્ક્રિપ્ટ કરો છો અને તમારો પાસફ્રેઝ ખોવાઈ જાય છે, તો તમે તમારા બધા બિટકોઇન્સ ગુમાવશો!</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation type="unfinished">શું તમે ખરેખર તમારા પાકીટને એન્ક્રિપ્ટ કરવા માંગો છો?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation type="unfinished">પાકીટ એન્ક્રિપ્ટ થયેલ</translation>
    </message>
    <message>
        <source>Your wallet is now encrypted. </source>
        <translation type="unfinished">તમારું વૉલેટ હવે એન્ક્રિપ્ટેડ છે.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation type="unfinished">વૉલેટ એન્ક્રિપ્શન નિષ્ફળ થયું.</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message>
        <source>Amount</source>
        <translation type="unfinished">રકમ</translation>
    </message>
    <message>
        <source>Inbound</source>
        <extracomment>An inbound connection from a peer. An inbound connection is a connection initiated by a peer.</extracomment>
        <translation type="unfinished">અંદરનું</translation>
    </message>
    <message>
        <source>Outbound</source>
        <extracomment>An outbound connection to a peer. An outbound connection is a connection initiated by us.</extracomment>
        <translation type="unfinished">બહારનું </translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Create a new wallet</source>
        <translation type="unfinished">નવું વૉલેટ બનાવો</translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to Bitcoin network.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Amount</source>
        <translation type="unfinished">રકમ</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">લેબલ નથી</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>%n GB of space available</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(sufficient to restore backups %n day(s) old)</source>
        <extracomment>Explanatory text on the capability of the current prune target.</extracomment>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Welcome</source>
        <translation type="unfinished">સ્વાગત છે</translation>
    </message>
    <message>
        <source>Welcome to %1.</source>
        <translation type="unfinished">સ્વાગત છે %1.</translation>
    </message>
    </context>
<context>
    <name>ModalOverlay</name>
    <message>
        <source>Hide</source>
        <translation type="unfinished">છુપાવો</translation>
    </message>
    </context>
<context>
    <name>PeerTableModel</name>
    <message>
        <source>Age</source>
        <extracomment>Title of Peers Table column which indicates the duration (length of time) since the peer connection started.</extracomment>
        <translation type="unfinished">ઉંમર</translation>
    </message>
    <message>
        <source>Sent</source>
        <extracomment>Title of Peers Table column which indicates the total amount of network information we have sent to the peer.</extracomment>
        <translation type="unfinished">મોકલેલ</translation>
    </message>
    <message>
        <source>Address</source>
        <extracomment>Title of Peers Table column which contains the IP/Onion/I2P address of the connected peer.</extracomment>
        <translation type="unfinished">સરનામુ</translation>
    </message>
    <message>
        <source>Type</source>
        <extracomment>Title of Peers Table column which describes the type of peer connection. The "type" describes why the connection exists.</extracomment>
        <translation type="unfinished">પ્રકાર</translation>
    </message>
    <message>
        <source>Inbound</source>
        <extracomment>An Inbound Connection from a Peer.</extracomment>
        <translation type="unfinished">અંદરનું</translation>
    </message>
    <message>
        <source>Outbound</source>
        <extracomment>An Outbound Connection to a Peer.</extracomment>
        <translation type="unfinished">બહારનું </translation>
    </message>
</context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>Name</source>
        <translation type="unfinished">નામ </translation>
    </message>
    <message>
        <source>Sent</source>
        <translation type="unfinished">મોકલેલ</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>Show</source>
        <translation type="unfinished">બતાવો</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished">દૂર કરો</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Label</source>
        <translation type="unfinished">ચિઠ્ઠી</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">લેબલ નથી</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Hide</source>
        <translation type="unfinished">છુપાવો</translation>
    </message>
    <message numerus="yes">
        <source>Estimated to begin confirmation within %n block(s).</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">લેબલ નથી</translation>
    </message>
</context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Amount</source>
        <translation type="unfinished">રકમ</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Type</source>
        <translation type="unfinished">પ્રકાર</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">ચિઠ્ઠી</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">લેબલ નથી</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Comma separated file</source>
        <extracomment>Expanded name of the CSV file format. See: https://en.wikipedia.org/wiki/Comma-separated_values.</extracomment>
        <translation type="unfinished">અલ્પવિરામથી વિભાજિત ફાઇલ</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished">પ્રકાર</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">ચિઠ્ઠી</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">સરનામુ</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation type="unfinished">નિકાસ ની પ્ર્રાક્રિયા નિષ્ફળ ગયેલ છે</translation>
    </message>
    </context>
<context>
    <name>WalletFrame</name>
    <message>
        <source>Create a new wallet</source>
        <translation type="unfinished">નવું વૉલેટ બનાવો</translation>
    </message>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">&amp; નિકાસ કરો</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">હાલ માં પસંદ કરેલ માહિતી ને ફાઇલમાં નિકાસ કરો</translation>
    </message>
    </context>
</TS>